@@ -196,13 +196,17 @@ register_element_cls('a:sysClr',    CT_SystemColor)
 
 from .dml.fill import (  # noqa: E402
     CT_Blip, CT_BlipFillProperties, CT_GradientFillProperties,
-    CT_GroupFillProperties, CT_NoFillProperties, CT_PatternFillProperties,
+    CT_GradientStop, CT_GradientStopList, CT_GroupFillProperties,
+    CT_LinearShadeProperties, CT_NoFillProperties, CT_PatternFillProperties,
     CT_RelativeRect, CT_SolidColorFillProperties
 )
 register_element_cls('a:blip',      CT_Blip)
 register_element_cls('a:blipFill',  CT_BlipFillProperties)
 register_element_cls('a:gradFill',  CT_GradientFillProperties)
 register_element_cls('a:grpFill',   CT_GroupFillProperties)
+register_element_cls('a:gs',        CT_GradientStop)
+register_element_cls('a:gsLst',     CT_GradientStopList)
+register_element_cls('a:lin',       CT_LinearShadeProperties)
 register_element_cls('a:noFill',    CT_NoFillProperties)
 register_element_cls('a:pattFill',  CT_PatternFillProperties)
 register_element_cls('a:solidFill', CT_SolidColorFillProperties)
@@ -315,10 +319,13 @@ register_element_cls('a:tr',      CT_TableRow)
 
 
 from .slide import (  # noqa: E402
-    CT_CommonSlideData, CT_NotesMaster, CT_NotesSlide, CT_Slide,
-    CT_SlideLayout, CT_SlideLayoutIdList, CT_SlideLayoutIdListEntry,
-    CT_SlideMaster, CT_SlideTiming, CT_TimeNodeList, CT_TLMediaNodeVideo
+    CT_Background, CT_BackgroundProperties, CT_CommonSlideData,
+    CT_NotesMaster, CT_NotesSlide, CT_Slide, CT_SlideLayout,
+    CT_SlideLayoutIdList, CT_SlideLayoutIdListEntry, CT_SlideMaster,
+    CT_SlideTiming, CT_TimeNodeList, CT_TLMediaNodeVideo
 )
+register_element_cls('p:bg',             CT_Background)
+register_element_cls('p:bgPr',           CT_BackgroundProperties)
 register_element_cls('p:childTnLst',     CT_TimeNodeList)
 register_element_cls('p:cSld',           CT_CommonSlideData)
 register_element_cls('p:notes',          CT_NotesSlide)
